@@ -214,6 +214,12 @@ public:
 	{
 		return ((mapDiscovered[((y&hMask)<<wDec)+(x&wMask)]) & visionMask) != 0;
 	}
+	
+	//! Sets all map for all teams to discovered state
+	void setMapDiscovered(void)
+	{
+		memset(mapDiscovered, ~0u, w*h*sizeof(Uint32));
+	}
 
 	//! Returs true if map is currently discovered at position (x,y) for a given vision mask.
 	//! This mask represents which team's units and buildings we are allowed to see.
@@ -348,6 +354,16 @@ public:
 		Case& c=cases[((y&hMask)<<wDec)+(x&wMask)];
 		c.forbidden ^= c.forbidden &  Team::teamNumberToMask(teamNum);
 	}
+	
+	void addClearArea(int x, int y, Uint32 teamNum)
+	{
+		cases[((y&hMask)<<wDec)+(x&wMask)].clearArea |=  Team::teamNumberToMask(teamNum);
+	}
+	
+	void addGuardArea(int x, int y, Uint32 teamNum)
+	{
+		cases[((y&hMask)<<wDec)+(x&wMask)].guardArea |=  Team::teamNumberToMask(teamNum);
+	}
 
 	
 	bool isWater(int x, int y)
@@ -367,6 +383,11 @@ public:
 		return (getTerrain(x, y)<16);
 	}
 	
+	bool isGrass(unsigned pos)
+	{
+		return  (getTerrain(pos)<16);
+	}
+	
 	bool isSand(int x, int y)
 	{
 		int t=getTerrain(x, y);
@@ -588,6 +609,7 @@ public:
 	void expandLocalGradient(Uint8 *gradient);
 	
 	bool buildingAvailable(Building *building, bool canSwim, int x, int y, int *dist);
+	//!requests the next step (dx, dy) to take to get to the building from (x,y) provided the unit canSwim.
 	bool pathfindBuilding(Building *building, bool canSwim, int x, int y, int *dx, int *dy, bool verbose);
 	bool pathfindLocalRessource(Building *building, bool canSwim, int x, int y, int *dx, int *dy); // Used for all ressources mixed in clearing flags.
 	
@@ -827,8 +849,10 @@ protected:
 
 public:
 	Uint32 checkSum(bool heavy);
-	Sint32 warpDistSquare(int px, int py, int qx, int qy); //!< The distance between (px, py) and (qx, qy), warp-safe, but not rooted.
+	Sint32 warpDist1d(int p, int q, int l);///distance of coordinates p and q on a loop of length l
+	Sint32 warpDistSquare(int px, int py, int qx, int qy); //!< The distance^2 between (px, py) and (qx, qy), warp-safe.
 	Sint32 warpDistMax(int px, int py, int qx, int qy); //!< The max distance on x or y axis, between (px, py) and (qx, qy), warp-safe.
+	Sint32 warpDistSum(int px, int py, int qx, int qy); //!< The combined distance on x and r y axis, between (px, py) and (qx, qy), warp-safe.
 	bool isInLocalGradient(int ux, int uy, int bx, int by); //!< Return true if the unit @(ux, uy) is close enough of building @(bx, by).
 	void dumpGradient(Uint8 *gradient, const char *filename = "gradient.dump.pgm");
 
